@@ -14,7 +14,6 @@
 
 import tempfile
 
-from ironic_lib import metrics_utils
 from oslo_db import exception as db_exception
 from oslo_log import log
 from oslo_utils import excutils
@@ -24,8 +23,10 @@ from ironic.common import exception
 from ironic.common.glance_service import service_utils as glance_utils
 from ironic.common.i18n import _
 from ironic.common import lessee_sources
+from ironic.common import metrics_utils
 from ironic.common import states
 from ironic.common import swift
+from ironic.conductor import configdrive_utils
 from ironic.conductor import notification_utils as notify_utils
 from ironic.conductor import steps as conductor_steps
 from ironic.conductor import task_manager
@@ -206,6 +207,12 @@ def do_node_deploy(task, conductor_id=None, configdrive=None,
     utils.wipe_deploy_internal_info(task)
     try:
         if configdrive:
+            if (not CONF.conductor.disable_configdrive_check
+                    and 'metadata' in task.driver.network.capabilities):
+                # Network interface drivers in this interface have sufficient
+                # support to enable us to check/fix/regenerate metadata.
+                configdrive = configdrive_utils.check_and_fix_configdrive(
+                    task, configdrive)
             _store_configdrive(node, configdrive)
     except (exception.SwiftOperationError, exception.ConfigInvalid) as e:
         with excutils.save_and_reraise_exception():
@@ -340,6 +347,10 @@ def do_next_deploy_step(task, step_index):
         child_node_execution = step.get('execute_on_child_nodes', False)
         result = None
         try:
+            if async_steps.DEPLOYMENT_POLLING in node.driver_internal_info:
+                # We're going to execute a new step, we should delete any
+                # older/out of date option.
+                node.del_driver_internal_info(async_steps.DEPLOYMENT_POLLING)
             if not child_node_execution:
                 interface = getattr(task.driver, step.get('interface'))
                 LOG.info('Executing %(step)s on node %(node)s',
