@@ -21,6 +21,7 @@ from oslo_config import types
 from ironic.common import boot_modes
 from ironic.common.i18n import _
 from ironic.common import lessee_sources
+from ironic.conf import types as ir_types
 
 
 opts = [
@@ -278,7 +279,8 @@ opts = [
                       'partition image containing EFI boot loader. This image '
                       'will be used by ironic when building UEFI-bootable ISO '
                       'out of kernel and ramdisk. Required for UEFI boot from '
-                      'partition images.')),
+                      'partition images. Can be overridden per-architecture '
+                      'using the bootloader_by_arch option.')),
     cfg.MultiOpt('clean_step_priority_override',
                  item_type=types.Dict(),
                  default={},
@@ -494,7 +496,7 @@ opts = [
                        '[conductor]disable_deep_image_inspection to be set '
                        'to False.')),
     cfg.ListOpt('permitted_image_formats',
-                default=['raw', 'qcow2', 'iso'],
+                default=['raw', 'gpt', 'qcow2', 'iso'],
                 mutable=True,
                 help=_('The supported list of image formats which are '
                        'permitted for deployment with Ironic. If an image '
@@ -522,6 +524,49 @@ opts = [
                        'functionality by setting this option to True will '
                        'create a more secure environment, however it may '
                        'break users in an unexpected fashion.')),
+    cfg.BoolOpt('disable_zstandard_decompression',
+                default=False,
+                mutable=False,
+                help=_('Option to enable disabling transparent decompression '
+                       'of files which are compressed with Zstandard '
+                       'compression. This option is provided should operators '
+                       'wish to disable this functionality, otherwise it is '
+                       'automatically applied by the conductor should a '
+                       'compressed artifact be detected.')),
+    cfg.ListOpt('file_url_allowed_paths',
+                default=['/var/lib/ironic', '/shared/html', '/templates',
+                         '/opt/cache/files', '/vagrant'],
+                item_type=ir_types.ExplicitAbsolutePath(),
+                help=_(
+                    'List of paths that are allowed to be used as file:// '
+                    'URLs. Files in /boot, /dev, /etc, /proc, /sys and other'
+                    'system paths are always disallowed for security reasons. '
+                    'Any files in this path readable by ironic may be used as '
+                    'an image source when deploying. Setting this value to '
+                    '"" (empty) disables file:// URL support. Paths listed '
+                    'here are validated as absolute paths and will be rejected'
+                    'if they contain path traversal mechanisms, such as "..".'
+                )),
+    cfg.DictOpt('bootloader_by_arch',
+                default={},
+                help=_(
+                    'Bootloader ESP image parameter per node architecture. '
+                    'For example: x86_64:bootx64.efi,aarch64:grubaa64.efi. '
+                    'A node\'s cpu_arch property is used as the key to get '
+                    'the appropriate bootloader ESP image. If the node\'s '
+                    'cpu_arch is not in the dictionary, '
+                    'the [conductor]bootloader value will be used instead.'
+                )),
+    cfg.BoolOpt('disable_configdrive_check',
+                default=False,
+                mutable=True,
+                help=_('Option to disable operations which check and '
+                       'potentially fix up configuration drive contents, '
+                       'such as invalid network metadata values. When these '
+                       'issues are detected, and ironic is able to correct '
+                       'the data, Ironic will do so transparently. Setting '
+                       'this option to True will disable this '
+                       'functionality.')),
 ]
 
 
